==> haskell-asn1-parse-0.9.4-107-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-gtzJp4lPe11Vj9ppczGqv
key: asn1-parse-0.9.4-gtzJp4lPe11Vj9ppczGqv
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 97ff17f1cd495219a5114807cbd62e59
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-gtzJp4lPe11Vj9ppczGqv
depends:
    asn1-encoding-0.9.5-4d2qu1C5140EVy8vWh2yu
    asn1-types-0.3.3-DioBfHlr1F19GPBRFraLWv base-4.12.0.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.4-108-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-FhWjOH6e4gKC1Hi1kY4buB
key: asn1-parse-0.9.4-FhWjOH6e4gKC1Hi1kY4buB
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: c7bdca8535cc0b23391b2296a381827f
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-FhWjOH6e4gKC1Hi1kY4buB
depends:
    asn1-encoding-0.9.5-5KKZW1D8M3iFo1KmhlQDOR
    asn1-types-0.3.3-9kOIcKUQpBeIUvQhC8COjO base-4.12.0.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
